court\_scraper.platforms.ia package
===================================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   court_scraper.platforms.ia.pages
   court_scraper.platforms.ia.parsers

Submodules
----------

court\_scraper.platforms.ia.runner module
-----------------------------------------

.. automodule:: court_scraper.platforms.ia.runner
   :members:
   :undoc-members:
   :show-inheritance:

court\_scraper.platforms.ia.site module
---------------------------------------

.. automodule:: court_scraper.platforms.ia.site
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: court_scraper.platforms.ia
   :members:
   :undoc-members:
   :show-inheritance:
